@@ -66,19 +66,36 @@ public final class MethodType implements Serializable
 	, Constable, TypeDescriptor.OfMethod<Class<?>, MethodType>
 {
 	static final Class<?>[] EMTPY_PARAMS = new Class<?>[0];
+	static final Set<Class<?>> WRAPPER_SET;
+	static {
+		Class<?>[] wrappers = {Byte.class, Character.class, Double.class, Float.class, Integer.class, Long.class, Short.class, Boolean.class };
+		WRAPPER_SET = Collections.unmodifiableSet(new HashSet<Class<?>>(Arrays.asList(wrappers)));
+	}
 
 	private MethodTypeForm form;
-
+	
+	static final Class<?>[] primitivesArray = new Class<?>[26];
+	static {
+		primitivesArray['B' - 'A'] = byte.class;
+		primitivesArray['C' - 'A'] = char.class;
+		primitivesArray['D' - 'A'] = double.class;
+		primitivesArray['F' - 'A'] = float.class;
+		primitivesArray['I' - 'A'] = int.class;
+		primitivesArray['J' - 'A'] = long.class;
+		primitivesArray['S' - 'A'] = short.class;
+		primitivesArray['Z' - 'A'] = boolean.class;
+	}
+	
 	private static Map<MethodType, WeakReference<MethodType>> internTable = Collections.synchronizedMap(new WeakHashMap<MethodType, WeakReference<MethodType>>());
 	// lock object to control insertion of new MTs
 	static final class InternTableAddLock { }
 	private static InternTableAddLock internTableAddLock = new InternTableAddLock();
 	
 	@VMCONSTANTPOOL_FIELD
-	final Class<?> rtype;
+	final Class<?> returnType;
 	
 	@VMCONSTANTPOOL_FIELD
-	final Class<?>[] ptypes;
+	final Class<?>[] arguments;
 
 	@VMCONSTANTPOOL_FIELD
 	int argSlots;	// Number of stack slots used by the described args in the MethodType
@@ -113,12 +130,12 @@ public final class MethodType implements Serializable
 	 * Private constructor as MethodTypes need to be interned.  
 	 */
 	private MethodType(Class<?> rtype, Class<?>[] ptypes, boolean copyArguments) {
-		this.rtype = rtype;
+		returnType = rtype;
 		if (copyArguments) {
-			this.ptypes = new Class<?>[ptypes.length];
-			System.arraycopy(ptypes, 0, this.ptypes, 0, ptypes.length);
+			arguments = new Class<?>[ptypes.length];
+			System.arraycopy(ptypes, 0, arguments, 0, ptypes.length);
 		} else {
-			this.ptypes = ptypes;
+			arguments = ptypes;
 		}
 	}
 		
@@ -184,9 +201,9 @@ public final class MethodType implements Serializable
 	 */
 	public MethodType changeParameterType(int position, Class<?> type) {
 		//TODO: Should check that position is valid.
-		Class<?>[] newParameters = ptypes.clone();
+		Class<?>[] newParameters = arguments.clone();
 		newParameters[position] = type;
-		return MethodType.methodType(rtype, newParameters, false); 
+		return MethodType.methodType(returnType, newParameters, false); 
 	 }
 	
 	/**
@@ -196,7 +213,7 @@ public final class MethodType implements Serializable
 	 * @return a new MethodType with a changed return type
 	 */
 	public MethodType changeReturnType(Class<?> type){
-		return methodType(type, ptypes, false);
+		return methodType(type, arguments, false);
 	}
    
 	/**
@@ -209,22 +226,22 @@ public final class MethodType implements Serializable
 	 * @throws IndexOutOfBoundsException if the startPosition or endPosition are not valid indexes or if the startPosition is greater than the endPosition
      */
     public MethodType dropParameterTypes(int startPosition, int endPosition) throws IndexOutOfBoundsException {
-		if ((startPosition >= 0) && (endPosition >= 0) && (startPosition <= endPosition) && (endPosition <= ptypes.length)) {
+		if ((startPosition >= 0) && (endPosition >= 0) && (startPosition <= endPosition) && (endPosition <= arguments.length)) {
     		int delta = endPosition - startPosition;
-    		Class<?>[] newParameters = new Class<?>[ptypes.length - delta];
-    		System.arraycopy(ptypes, 0, newParameters, 0, startPosition);
-    		System.arraycopy(ptypes, endPosition, newParameters, startPosition, ptypes.length - endPosition);
-    		return methodType(rtype, newParameters, false);
+    		Class<?>[] newParameters = new Class<?>[arguments.length - delta];
+    		System.arraycopy(arguments, 0, newParameters, 0, startPosition);
+    		System.arraycopy(arguments, endPosition, newParameters, startPosition, arguments.length - endPosition);
+    		return methodType(returnType, newParameters, false);
 		}
     	throw new IndexOutOfBoundsException("'" + this + "' startPosition=" + startPosition + " endPosition=" + endPosition);  //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$
 	}
     
     /* Internal helper method that is equivalent to dropParameterTypes(0, 1) */
     MethodType dropFirstParameterType() throws IndexOutOfBoundsException {
-    	if (ptypes.length == 0) {
+    	if (arguments.length == 0) {
     		throw new IndexOutOfBoundsException();
     	}
-    	return methodType(rtype, Arrays.copyOfRange(ptypes, 1, ptypes.length), false);
+    	return methodType(returnType, Arrays.copyOfRange(arguments, 1, arguments.length), false);
 	}
     
 	  
@@ -244,10 +261,10 @@ public final class MethodType implements Serializable
 		}
 
 		MethodType that = (MethodType) x;
-		if ((this.ptypes.length != that.ptypes.length) || (this.rtype != that.rtype)) {
+		if ((this.arguments.length != that.arguments.length) || (this.returnType != that.returnType)) {
 			return false;
 		}
-		return Arrays.equals(this.ptypes, that.ptypes);
+		return Arrays.equals(this.arguments, that.arguments);
 	}
 	
 	/**
@@ -257,13 +274,13 @@ public final class MethodType implements Serializable
 	 * @return a new MethodType with all non-primitive or void return type and parameters changed to Object.
 	 */
 	public MethodType erase() {
-		Class<?>[] newParameters = ptypes.clone();
+		Class<?>[] newParameters = arguments.clone();
 		for (int i= 0; i < newParameters.length; i++){
 			if (!newParameters[i].isPrimitive()) {
 				newParameters[i] = Object.class;
 			}
 		}
-		return methodType(rtype.isPrimitive() ? rtype : Object.class, newParameters, false);
+		return methodType(returnType.isPrimitive() ? returnType : Object.class, newParameters, false);
 	}
 	
 	
@@ -345,6 +362,32 @@ public final class MethodType implements Serializable
 		
 		return methodType(returnType, types);
 	}
+	
+	/**
+	 * This helper calls MethodType.fromMethodDescriptorString(...) or 
+	 * MethodType.fromMethodDescriptorStringAppendArg(...) but throws 
+	 * NoClassDefFoundError instead of TypeNotPresentException during 
+	 * the VM resolve stage.
+	 *
+	 * @param methodDescriptor - the method descriptor string
+	 * @param loader - the ClassLoader to be used
+	 * @param appendArgumentType - an extra argument type
+	 *
+	 * @return a MethodType object representing the method descriptor string
+	 *
+	 * @throws IllegalArgumentException - if the string is not well-formed
+	 * @throws NoClassDefFoundError - if a named type cannot be found
+	 */
+	static final MethodType vmResolveFromMethodDescriptorString(String methodDescriptor, ClassLoader loader, Class<?> appendArgumentType) throws Throwable {
+		try {
+			if (null == appendArgumentType) {
+				return MethodType.fromMethodDescriptorString(methodDescriptor, loader);
+			}
+			return MethodType.fromMethodDescriptorStringAppendArg(methodDescriptor, loader, appendArgumentType);
+		} catch (TypeNotPresentException e) {
+			throw throwNoClassDefFoundError(e);
+		}
+	}
 
 	/**
 	 * Helper method to throw NoClassDefFoundError if the cause of TypeNotPresentException 
@@ -366,6 +409,72 @@ public final class MethodType implements Serializable
 		}
 		throw e;
 	}
+	
+	/*
+	 * Convert the string from bytecode format to the format needed for ClassLoader#loadClass().
+	 * Change all '/' to '.'.
+	 * Remove the 'L' & ';' from objects, unless they are array classes.
+	 */
+	private static final Class<?> nonPrimitiveClassFromString(String name, ClassLoader classLoader) {
+		try {
+			name = name.replace('/', '.');
+			if (name.indexOf('L') == 0) {
+				// Remove the 'L' and ';'
+				name = name.substring(1, name.length() - 1);
+			}
+			return Class.forName(name, false, classLoader);
+		} catch(ClassNotFoundException e){
+			throw new TypeNotPresentException(name, e);
+		}
+	}
+
+	/*
+	 * Parses the first parameter in a descriptor string into a Class object.
+	 * The Class object is append to given ArrayList and the current string index is returned.
+	 */
+	static final int parseIntoClass(char[] signature, int index, ArrayList<Class<?>> args, ClassLoader classLoader, String descriptor) {
+		char current = signature[index];
+		Class<?> c;			
+		
+		if ((current == 'L') || (current == '[')) {
+			int start = index;
+			while(signature[index] == '[') {
+				index++;
+			}
+			String name;
+			if (signature[index] != 'L') {
+				name = descriptor.substring(start, index + 1);
+			} else { 
+				int end = descriptor.indexOf(';', index);
+				if (end == -1) {
+					// K05d6 = malformed method descriptor: {0}
+					throw new IllegalArgumentException(Msg.getString("K05d6", descriptor)); //$NON-NLS-1$
+				}
+				name = descriptor.substring(start, end + 1);
+				index = end;
+			}
+			c = nonPrimitiveClassFromString(name, classLoader);
+		} else {
+			try {
+				c = primitivesArray[current - 'A'];
+			} catch(ArrayIndexOutOfBoundsException e) {
+				c = null;
+			}
+			if (c == null) {
+				if (current == 'V') {
+					// lazily add 'V' to work around load ordering issues
+					primitivesArray['V' - 'A'] = void.class;
+					c = void.class;
+				} else {
+					// K05d7 = not a primitive: {0}
+					throw new IllegalArgumentException(Msg.getString("K05d7", current)); //$NON-NLS-1$
+				}
+			}
+		}
+		args.add(c);
+
+		return index;
+	}
 
 	/*
 	 * Parse the MethodDescriptor string into a list of Class objects.  The last class in the list
@@ -403,7 +512,7 @@ public final class MethodType implements Serializable
 				continue;
 			}
 
-			index = MethodTypeHelper.parseIntoClass(signature, index, args, classLoader, methodDescriptor);
+			index = parseIntoClass(signature, index, args, classLoader, methodDescriptor);
 			index++;
 		}
 		return args;
@@ -416,7 +525,7 @@ public final class MethodType implements Serializable
 	 * @return a new MethodType with both return and parameter types changed to Object
 	 */
 	public MethodType generic() {
-		return genericMethodType(ptypes.length);
+		return genericMethodType(arguments.length);
 	}
 	
 	
@@ -429,8 +538,8 @@ public final class MethodType implements Serializable
 	 */
 	public int hashCode(){
 		if (hashcode == 0) {
-			int hash = 31 + rtype.hashCode();
-			for (Class<?> c : ptypes) {
+			int hash = 31 + returnType.hashCode();
+			for (Class<?> c : arguments) {
 				hash = 31 * hash + c.hashCode();
 			}
 			hashcode = hash;
@@ -446,10 +555,10 @@ public final class MethodType implements Serializable
 	 * @return whether the MethodType contains any primitive types
 	 */
 	public boolean hasPrimitives(){
-		if (rtype.isPrimitive()){
+		if (returnType.isPrimitive()){
 			return true;
 		}
-		for(Class<?> c : ptypes){
+		for(Class<?> c : arguments){
 			if (c.isPrimitive()) {
 				return true;
 			}
@@ -467,11 +576,11 @@ public final class MethodType implements Serializable
 	 * @return whether the MethodType contains any wrapper types
 	 */
 	public boolean hasWrappers() {
-		if (MethodTypeHelper.WRAPPER_SET.contains(rtype) || (rtype == Void.class)){
+		if (WRAPPER_SET.contains(returnType) || (returnType == Void.class)){
 			return true;
 		}
-		for(Class<?> c : ptypes){
-			if (MethodTypeHelper.WRAPPER_SET.contains(c)){
+		for(Class<?> c : arguments){
+			if (WRAPPER_SET.contains(c)){
 				return true;
 			}
 		}
@@ -488,7 +597,7 @@ public final class MethodType implements Serializable
 	 * @throws IndexOutOfBoundsException if position is less than 0 or greater than than the number of arguments
 	 */
 	public MethodType insertParameterTypes(int position, Class<?>... types) throws IndexOutOfBoundsException {
-		if (position < 0 || position > ptypes.length) {
+		if (position < 0 || position > arguments.length) {
 			throw new IndexOutOfBoundsException();
 		}
 		int typesLength = types.length;
@@ -497,14 +606,14 @@ public final class MethodType implements Serializable
 			return this;
 		}
 		
-		Class<?>[] params = new Class<?>[ptypes.length + typesLength];
+		Class<?>[] params = new Class<?>[arguments.length + typesLength];
 		// Copy from 0 -> position out of the existing MethodType arguments
-		System.arraycopy(ptypes, 0, params, 0, position);
+		System.arraycopy(arguments, 0, params, 0, position);
 		// Copy from position -> types.length out of the types[] array
 		System.arraycopy(types, 0, params, position, typesLength);
 		// Copy from position + types.length -> params.length out of the existing MT arguments
-		System.arraycopy(ptypes, position, params, position + typesLength, ptypes.length - position);
-		return methodType(rtype, params, false);
+		System.arraycopy(arguments, position, params, position + typesLength, arguments.length - position);
+		return methodType(returnType, params, false);
 	}
 	
 	/**
@@ -590,9 +699,9 @@ public final class MethodType implements Serializable
 				return type;
 			}
 			
-			int stackSlots = ptypes.length;
+			int stackSlots = arguments.length;
 			
-			for(Class<?> c : ptypes) {
+			for(Class<?> c : arguments) {
 				c.getClass();	// Implicit nullcheck
 				if ((c == double.class) || (c == long.class)) {
 					stackSlots++;
@@ -608,7 +717,7 @@ public final class MethodType implements Serializable
 			argSlots = stackSlots;
 
 			/* initialize expensive state */
-			stackDescriptionBits = stackDescriptionBits(ptypes, argSlots);
+			stackDescriptionBits = stackDescriptionBits(arguments, argSlots);
 			methodDescriptor = createMethodDescriptorString();
 
 			MethodType tenured = makeTenured(this);
@@ -667,7 +776,7 @@ public final class MethodType implements Serializable
 	 * @return a MethodType object made by changing the return type of the passed in MethodType
 	 */
 	public static MethodType methodType(Class<?> returnType, MethodType methodType) {
-		return methodType(returnType, methodType.ptypes, false);
+		return methodType(returnType, methodType.arguments, false);
 	}
 
 	/**
@@ -718,7 +827,7 @@ public final class MethodType implements Serializable
 	 * @return the parameter types as an array
 	 */
 	public Class<?>[] parameterArray() {
-		return ptypes.clone();
+		return arguments.clone();
 	}
 
 	/**
@@ -727,7 +836,7 @@ public final class MethodType implements Serializable
 	 * @return the number of parameters
 	 */
 	public int parameterCount() {
-		return ptypes.length;
+		return arguments.length;
 	}
 
 	/**
@@ -736,7 +845,7 @@ public final class MethodType implements Serializable
 	 * @return array of arguments
 	 */
 	Class<?>[] ptypes() {
-		return ptypes;
+		return arguments;
 	}
 
 	/**
@@ -747,7 +856,7 @@ public final class MethodType implements Serializable
 	 * @return the parameter types as a List
 	 */
 	public List<Class<?>> parameterList() {
-		List<Class<?>> list = Arrays.asList(ptypes.clone()); 
+		List<Class<?>> list = Arrays.asList(arguments.clone()); 
 		return Collections.unmodifiableList(list);
 	}     
 
@@ -759,14 +868,14 @@ public final class MethodType implements Serializable
 	 * @throws IndexOutOfBoundsException if position is less than 0 or an invalid argument index.
 	 */
 	public Class<?> parameterType(int position) throws IndexOutOfBoundsException {
-		return ptypes[position];
+		return arguments[position];
 	}
 	
 	/**
 	 * @return the type of the return
 	 */
 	public Class<?> returnType() {
-		return rtype;
+		return returnType;
 	}
 	
 	/**
@@ -778,8 +887,8 @@ public final class MethodType implements Serializable
 	public
 	Class<?> lastParameterType() {
 		Class<?> result = void.class;
-		if (ptypes.length > 0) {
-			result = ptypes[ptypes.length - 1];
+		if (arguments.length > 0) {
+			result = arguments[arguments.length - 1];
 		}
 		return result;
 	}
@@ -796,11 +905,11 @@ public final class MethodType implements Serializable
 	
 	private String createMethodDescriptorString(){
 		StringBuilder sb= new StringBuilder("("); //$NON-NLS-1$
-		for (Class<?> c : ptypes){
-			sb.append(MethodTypeHelper.getBytecodeStringName(c));
+		for (Class<?> c : arguments){
+			sb.append(getBytecodeStringName(c));
 		}
 		sb.append(")"); //$NON-NLS-1$
-		sb.append(MethodTypeHelper.getBytecodeStringName(rtype));
+		sb.append(getBytecodeStringName(returnType));
 		return sb.toString();
 	}
 	
@@ -814,14 +923,14 @@ public final class MethodType implements Serializable
 	@Override
 	public String toString(){
 		StringBuilder sb = new StringBuilder("("); //$NON-NLS-1$
-		for (int i = 0; i < ptypes.length; i++){
-			sb.append(ptypes[i].getSimpleName());
-			if (i < (ptypes.length - 1)) {
+		for (int i = 0; i < arguments.length; i++){
+			sb.append(arguments[i].getSimpleName());
+			if (i < (arguments.length - 1)) {
 				sb.append(","); //$NON-NLS-1$
 			}
 		}
 		sb.append(")"); //$NON-NLS-1$
-		sb.append(rtype.getSimpleName());
+		sb.append(returnType.getSimpleName());
 		return sb.toString();
 	}
 
@@ -834,12 +943,12 @@ public final class MethodType implements Serializable
 	 * @see #wrap()
 	 */
 	public MethodType unwrap(){
-		Class<?>[] args = ptypes.clone();
+		Class<?>[] args = arguments.clone();
 		for(int i = 0; i < args.length; i++){
-			args[i] = MethodTypeHelper.unwrapPrimitive(args[i]);
+			args[i] = unwrapPrimitive(args[i]);
 		}
-		Class<?> unwrappedReturnType = MethodTypeHelper.unwrapPrimitive(rtype);
-		if (MethodTypeHelper.unwrapPrimitive(rtype) == Void.class) {
+		Class<?> unwrappedReturnType = unwrapPrimitive(returnType);
+		if (unwrapPrimitive(returnType) == Void.class) {
 			unwrappedReturnType = void.class;
 		}
 		return methodType(unwrappedReturnType, args, false);
@@ -854,11 +963,11 @@ public final class MethodType implements Serializable
 	 * @see #unwrap()
 	 */
 	public MethodType wrap(){
-		Class<?>[] args = ptypes.clone();
+		Class<?>[] args = arguments.clone();
 		for(int i = 0; i < args.length; i++){
-			args[i] = MethodTypeHelper.wrapPrimitive(args[i]);
+			args[i] = wrapPrimitive(args[i]);
 		}
-		return methodType(MethodTypeHelper.wrapPrimitive(rtype), args, false);
+		return methodType(wrapPrimitive(returnType), args, false);
 	}
 	
 	/**
@@ -888,11 +997,126 @@ public final class MethodType implements Serializable
 		if (classes == null) {
 			throw new NullPointerException();
 		}
-		ArrayList<Class<?>> combinedParameters = new ArrayList<Class<?>>(Arrays.asList(ptypes));
+		ArrayList<Class<?>> combinedParameters = new ArrayList<Class<?>>(Arrays.asList(arguments));
 		combinedParameters.addAll(classes);
-		return methodType(rtype, combinedParameters);
+		return methodType(returnType, combinedParameters);
 	}
-
+	
+	/**
+	 * Returns the appropriate wrapper class or the original class
+	 * @param primitiveClass The class to convert to a wrapper class
+	 * @return The wrapper class or the original class if no wrapper is available
+	 */
+	static Class<?> wrapPrimitive(Class<?> primitveClass) {
+		if (primitveClass.isPrimitive()) {
+			if (int.class == primitveClass){ //I
+				return Integer.class;
+			}
+			if (long.class == primitveClass){ //J
+				return Long.class;
+			}
+			if (byte.class == primitveClass){	//B
+				return Byte.class;
+			}
+			if (char.class == primitveClass){ //C
+				return Character.class;
+			}
+			if (double.class == primitveClass){ //D
+				return Double.class;
+			}
+			if (float.class == primitveClass){ //F
+				return Float.class;
+			}
+			if (boolean.class == primitveClass){ //Z
+				return Boolean.class;
+			}
+			if (void.class == primitveClass) {
+				return Void.class;
+			}
+			if (short.class == primitveClass){ //S
+				return Short.class;
+			}
+		}
+		return primitveClass;
+	}
+	
+	
+	/**
+	 * Takes a class and returns the corresponding primitive if one exists.
+	 * @param wrapperClass The class to check for primitive classes.
+	 * @return The corresponding primitive class or the input class.
+	 */
+	static Class<?> unwrapPrimitive(Class<?> wrapperClass){
+		if (Integer.class == wrapperClass) { //I
+			return int.class;
+		}
+		if (Long.class == wrapperClass) { //J
+			return long.class;
+		}
+		if (Byte.class == wrapperClass) {	//B
+			return byte.class;
+		}
+		if (Character.class == wrapperClass) { //C
+			return char.class;
+		}
+		if (Double.class == wrapperClass) { //D
+			return double.class;
+		}
+		if (Float.class == wrapperClass) { //F
+			return float.class;
+		}
+		if (Short.class == wrapperClass) { //S
+			return short.class;
+		}
+		if (Boolean.class == wrapperClass) { //Z
+			return boolean.class;
+		}
+		return wrapperClass;
+	}
+	
+	/* The string returned by this method should be in sync with Class.descriptorString() */
+	static String getBytecodeStringName(Class<?> c){
+		if (c.isPrimitive()) {
+			if (c == int.class) {
+				return "I"; //$NON-NLS-1$
+			} else if (c == long.class) {
+				return "J"; //$NON-NLS-1$
+			} else if (c == byte.class) {
+				return "B"; //$NON-NLS-1$
+			} else if (c == boolean.class) {
+				return "Z"; //$NON-NLS-1$
+			} else if (c == void.class) {
+				return "V"; //$NON-NLS-1$
+			} else if (c == char.class) {
+				return "C"; //$NON-NLS-1$
+			} else if (c == double.class) {
+				return "D"; //$NON-NLS-1$
+			} else if (c == float.class) {
+				return "F"; //$NON-NLS-1$
+			} else if (c == short.class) {
+				return "S"; //$NON-NLS-1$
+			}
+		}
+		Class<?> clazz = c;
+		if (c.isArray()) {
+			clazz = c.getComponentType();
+			while (clazz.isArray()) {
+				clazz = clazz.getComponentType();
+			}
+		}
+		String name = c.getName().replace('.', '/');
+		if (clazz.isHidden()) {
+			/* keep the last "." before romaddress for hidden classes */
+			int index = name.lastIndexOf('/');
+			name = name.substring(0, index) + '.' + name.substring(index + 1,name.length());
+		}
+		
+		if (c.isArray()) {
+			return name;
+		}
+		return "L"+ name + ";"; //$NON-NLS-1$ //$NON-NLS-2$
+	}
+	
 	/*
 	 * Implements JSR 292 serialization spec.
 	 * Write the MethodType without writing the field names.
@@ -914,8 +1138,8 @@ public final class MethodType implements Serializable
 	 */
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
 		try {
-			final Field fReturnType = getClass().getDeclaredField("rtype"); //$NON-NLS-1$
-			final Field fArguments = getClass().getDeclaredField("ptypes"); //$NON-NLS-1$
+			final Field fReturnType = getClass().getDeclaredField("returnType"); //$NON-NLS-1$
+			final Field fArguments = getClass().getDeclaredField("arguments"); //$NON-NLS-1$
 			AccessController.doPrivileged(new PrivilegedAction<Object>() {
 				public Object run() {
 						fReturnType.setAccessible(true);
@@ -964,7 +1188,7 @@ public final class MethodType implements Serializable
 		}
 		return invoker;
 	}
-
+	
 	static MethodType makeImpl(Class<?> rtype, Class<?>[] ptypes, boolean arg) {
 		throw OpenJDKCompileStub.OpenJDKCompileStubThrowError();
 	}
@@ -986,7 +1210,7 @@ public final class MethodType implements Serializable
 	}
 	
 	Class<?> rtype() {
-		return rtype;
+		return returnType;
 	}
 
 	MethodType asCollectorType(Class<?> clz, int num1, int num2) {
@@ -1018,13 +1242,13 @@ public final class MethodType implements Serializable
 	 */
 	public Optional<MethodTypeDesc> describeConstable() {
 		try {
-			ClassDesc returnDesc = rtype.describeConstable().orElseThrow();
+			ClassDesc returnDesc = returnType.describeConstable().orElseThrow();
 
 			/* convert parameter classes to ClassDesc */
-			final int argumentsLength = ptypes.length;
+			final int argumentsLength = arguments.length;
 			ClassDesc[] paramDescs = new ClassDesc[argumentsLength];
 			for (int i = 0; i < argumentsLength; i++) {
-				paramDescs[i] = ptypes[i].describeConstable().orElseThrow();
+				paramDescs[i] = arguments[i].describeConstable().orElseThrow();
 			}
 
 			/* create MethodTypeDesc */
@@ -1035,3 +1259,4 @@ public final class MethodType implements Serializable
 		}
 	}
 }
+
